PyTorch scaling test
====================

.. include:: ../../../tutorials/distributed-ml/torch-scaling-test/README.md
   :parser: myst_parser.sphinx_
   :end-before: Below follows an example of


Below follows an example of scalability plot generated by ``itwinai scalability-report``:

.. image:: ../../../tutorials/distributed-ml/torch-scaling-test/img/report.png
